==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway.md <==
# AwsStorageGatewayAmazonS3FileGateway


```text
aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway
```

```text
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')
```



| Illustration | AwsStorageGatewayAmazonS3FileGateway | AwsStorageGatewayAmazonS3FileGatewayCard | AwsStorageGatewayAmazonS3FileGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway.png) | ![illustration for AwsStorageGatewayAmazonS3FileGateway](../../../aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway.Local.png) | ![illustration for AwsStorageGatewayAmazonS3FileGatewayCard](../../../aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGatewayCard.Local.png) | ![illustration for AwsStorageGatewayAmazonS3FileGatewayGroup](../../../aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGatewayGroup.Local.png) |




## AwsStorageGatewayAmazonS3FileGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayAmazonS3FileGateway
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')

' renders the element
AwsStorageGatewayAmazonS3FileGateway('AwsStorageGatewayAmazonS3FileGateway', 'Aws Storage Gateway Amazon S3 File Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayAmazonS3FileGateway
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')

' renders the element
AwsStorageGatewayAmazonS3FileGateway('AwsStorageGatewayAmazonS3FileGateway', 'Aws Storage Gateway Amazon S3 File Gateway', 'an optional tech label')
@enduml
```

## AwsStorageGatewayAmazonS3FileGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayAmazonS3FileGatewayCard
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')

' renders the element
AwsStorageGatewayAmazonS3FileGatewayCard('AwsStorageGatewayAmazonS3FileGatewayCard', 'Aws Storage Gateway Amazon S3 File Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayAmazonS3FileGatewayCard
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')

' renders the element
AwsStorageGatewayAmazonS3FileGatewayCard('AwsStorageGatewayAmazonS3FileGatewayCard', 'Aws Storage Gateway Amazon S3 File Gateway Card', 'an optional description')
@enduml
```

## AwsStorageGatewayAmazonS3FileGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayAmazonS3FileGatewayGroup
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')

' renders the element
AwsStorageGatewayAmazonS3FileGatewayGroup('AwsStorageGatewayAmazonS3FileGatewayGroup', 'Aws Storage Gateway Amazon S3 File Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayAmazonS3FileGatewayGroup
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')

' renders the element
AwsStorageGatewayAmazonS3FileGatewayGroup('AwsStorageGatewayAmazonS3FileGatewayGroup', 'Aws Storage Gateway Amazon S3 File Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway.md <==
# AwsStorageGatewayAmazonS3FileGateway


```text
aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway
```

```text
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')
```



| Illustration | AwsStorageGatewayAmazonS3FileGateway | AwsStorageGatewayAmazonS3FileGatewayCard | AwsStorageGatewayAmazonS3FileGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway.png) | ![illustration for AwsStorageGatewayAmazonS3FileGateway](../../../aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway.Local.png) | ![illustration for AwsStorageGatewayAmazonS3FileGatewayCard](../../../aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGatewayCard.Local.png) | ![illustration for AwsStorageGatewayAmazonS3FileGatewayGroup](../../../aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGatewayGroup.Local.png) |




## AwsStorageGatewayAmazonS3FileGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayAmazonS3FileGateway
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')

' renders the element
AwsStorageGatewayAmazonS3FileGateway('AwsStorageGatewayAmazonS3FileGateway', 'Aws Storage Gateway Amazon S3 File Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayAmazonS3FileGateway
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')

' renders the element
AwsStorageGatewayAmazonS3FileGateway('AwsStorageGatewayAmazonS3FileGateway', 'Aws Storage Gateway Amazon S3 File Gateway', 'an optional tech label')
@enduml
```

## AwsStorageGatewayAmazonS3FileGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayAmazonS3FileGatewayCard
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')

' renders the element
AwsStorageGatewayAmazonS3FileGatewayCard('AwsStorageGatewayAmazonS3FileGatewayCard', 'Aws Storage Gateway Amazon S3 File Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayAmazonS3FileGatewayCard
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')

' renders the element
AwsStorageGatewayAmazonS3FileGatewayCard('AwsStorageGatewayAmazonS3FileGatewayCard', 'Aws Storage Gateway Amazon S3 File Gateway Card', 'an optional description')
@enduml
```

## AwsStorageGatewayAmazonS3FileGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayAmazonS3FileGatewayGroup
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')

' renders the element
AwsStorageGatewayAmazonS3FileGatewayGroup('AwsStorageGatewayAmazonS3FileGatewayGroup', 'Aws Storage Gateway Amazon S3 File Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayAmazonS3FileGatewayGroup
include('aws-q3-2021/Resource/Storage/AwsStorageGatewayAmazonS3FileGateway')

' renders the element
AwsStorageGatewayAmazonS3FileGatewayGroup('AwsStorageGatewayAmazonS3FileGatewayGroup', 'Aws Storage Gateway Amazon S3 File Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
